@@ -469,11 +469,13 @@ object_instance_new_resolve_no_info(JSContext       *context,
 
 
         if (method_info != NULL) {
-            if (gjs_define_function(context, obj, priv->gtype,
-                                    (GICallableInfo *)method_info)) {
-                *objp = obj;
-            } else {
-                ret = JS_FALSE;
+            if (g_function_info_get_flags (method_info) & GI_FUNCTION_IS_METHOD) {
+                if (gjs_define_function(context, obj, priv->gtype,
+                                        (GICallableInfo *)method_info)) {
+                    *objp = obj;
+                } else {
+                    ret = JS_FALSE;
+                }
             }
 
             g_base_info_unref( (GIBaseInfo*) method_info);
@@ -621,20 +623,22 @@ object_instance_new_resolve(JSContext *context,
         _gjs_log_info_usage((GIBaseInfo*) method_info);
 #endif
 
-        gjs_debug(GJS_DEBUG_GOBJECT,
-                  "Defining method %s in prototype for %s (%s.%s)",
-                  g_base_info_get_name( (GIBaseInfo*) method_info),
-                  g_type_name(priv->gtype),
-                  g_base_info_get_namespace( (GIBaseInfo*) priv->info),
-                  g_base_info_get_name( (GIBaseInfo*) priv->info));
+        if (g_function_info_get_flags (method_info) & GI_FUNCTION_IS_METHOD) {
+            gjs_debug(GJS_DEBUG_GOBJECT,
+                      "Defining method %s in prototype for %s (%s.%s)",
+                      g_base_info_get_name( (GIBaseInfo*) method_info),
+                      g_type_name(priv->gtype),
+                      g_base_info_get_namespace( (GIBaseInfo*) priv->info),
+                      g_base_info_get_name( (GIBaseInfo*) priv->info));
 
-        if (gjs_define_function(context, *obj, priv->gtype, method_info) == NULL) {
-            g_base_info_unref( (GIBaseInfo*) method_info);
-            goto out;
+            if (gjs_define_function(context, *obj, priv->gtype, method_info) == NULL) {
+                g_base_info_unref( (GIBaseInfo*) method_info);
+                goto out;
+            }
+
+            *objp = *obj; /* we defined the prop in obj */
         }
 
-        *objp = *obj; /* we defined the prop in obj */
-
         g_base_info_unref( (GIBaseInfo*) method_info);
     }
 
@@ -1847,11 +1851,11 @@ JSFunctionSpec gjs_object_instance_proto_funcs[] = {
     { NULL }
 };
 
-static JSBool
-gjs_define_static_methods(JSContext    *context,
-                          JSObject     *constructor,
-                          GType         gtype,
-                          GIObjectInfo *object_info)
+JSBool
+gjs_object_define_static_methods(JSContext    *context,
+                                 JSObject     *constructor,
+                                 GType         gtype,
+                                 GIObjectInfo *object_info)
 {
     int i;
     int n_methods;
@@ -1993,7 +1997,7 @@ gjs_define_object_class(JSContext      *context,
               constructor_name, prototype, JS_GetClass(prototype), in_object);
 
     if (info)
-        gjs_define_static_methods(context, constructor, gtype, info);
+        gjs_object_define_static_methods(context, constructor, gtype, info);
 
     value = OBJECT_TO_JSVAL(gjs_gtype_create_gtype_wrapper(context, gtype));
     JS_DefineProperty(context, constructor, "$gtype", value,
